/*******************************************************************************
* Copyright (C) 2005, 2006 Novell, Inc. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
*  - Redistributions of source code must retain the above copyright notice,
*    this list of conditions and the following disclaimer.
*
*  - Redistributions in binary form must reproduce the above copyright notice,
*    this list of conditions and the following disclaimer in the documentation
*    and/or other materials provided with the distribution.
*
*  - Neither the name of Novell, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived from this
*    software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL Novell, Inc. OR THE CONTRIBUTORS
* BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*
* Author: Jon Carey (jcarey@novell.com)
******************************************************************************/
#ifndef CMPIUTIL_BASE_H_GUARD__
#define CMPIUTIL_BASE_H_GUARD__

#ifdef __cplusplus
extern "C" {
#endif

#include <stdlib.h>
#include <stdint.h>

/**
 * Sleep for a given number of milliseconds.
 * @param ms The number of milliseconds to sleep for.
 */
void cmpiutilMilliSleep(
	uint32_t ms);

/**
 * Sleep for a given number of seconds.
 * @param secs The number of seconds to sleep for.
 */
void cmpiutilSecondSleep(
	uint32_t secs);

/**
 * Get the host name of the system.
 * @param hostNameOut a pointer to a buffer where the host name will be
 *  copied on success.
 * @param hostNameOutLen The length of the buffer pointed to by the
 *  hostNameOut parameter.
 * @return A pointer to the host name on success (hostNameOut).
 *  Otherwise NULL on error.
 */
const char* cmpiutilGetHostName(
	char* hostNameOut,
	size_t hostNameOutLen);

/**
 * Get the name of the Operating System CIM class name.
 * @return A pointer to the Operating system CIM classname.
 */
const char* cmpiutilGetOperatingSystemClassName(void);

/**
 * Get the name of the Computer System CIM class name;
 * @return A pointer to the computer system CIM class name.
 */
const char* cmpiutilGetComputerSystemClassName(void);

/**
 * Get the name of this computer system.
 * @param csNameOut a pointer to a buffer where the computer system name will
 *  be stored on success.
 * @param csNameOutLen The length of the buffer pointed by the csNameOut
 *  parameter.
 * @return A pointer to the computer system name on success (csNameOut).
 *  Otherwise NULL on error.
 */
const char* cmpiutilGetComputerSystemName(
	char* csNameOut,
	size_t csNameOutLen);

/**
 * Create an InstanceID string that can be used in the InstanceID property
 * that is common to many CIM classes. The results will be of the form:
 * 		"cmpiutil:<uniquePart>"
 * @param uniquePart A string that represents the unique part of the resulting
 *  InstanceID string.
 * @param instanceIdOut A pointer to a buffer where the InstanceID will be
 *  stored on success.
 * @param instanceIdOutLen The length of the buffer pointed to by the
 *  instanceIdOut parameter.
 * @return A pointer to the InstanceID string on success (instanceIDOut).
 *  Otherwise NULL on error.
 */
const char* cmpiutilMakeInstanceID(
	const char* uniquePart,
	char* instanceIdOut,
	size_t instanceIdOutLen);


/**
 * Get the install date of an RPM (as a time_t?)
 * @param rpmName The name of the rpm to get the install date for.
 */
unsigned long long
cmpiutilGetRPMInstallDate(
	const char *rpmName);



#ifdef __cplusplus
}
#endif

#endif
