/*******************************************************************************
* Copyright (C) 2005, 2006 Novell, Inc. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
*  - Redistributions of source code must retain the above copyright notice,
*    this list of conditions and the following disclaimer.
*
*  - Redistributions in binary form must reproduce the above copyright notice,
*    this list of conditions and the following disclaimer in the documentation
*    and/or other materials provided with the distribution.
*
*  - Neither the name of Novell, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived from this
*    software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL Novell, Inc. OR THE CONTRIBUTORS
* BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*
* Author: Norm Paxton (npaxton@novell.com)
******************************************************************************/
#ifndef TIME_SERVICE_UTILS_H_GUARD__
#define TIME_SERVICE_UTILS_H_GUARD__

#include <cmpidt.h>
#include <cmpift.h>
#include <cmpimacs.h>

#include <cmpiutil/base.h>
#include <cmpiutil/cmpiUtils.h>
#include <cmpiutil/cmpiSimpleAssoc.h>
#include <cmpiutil/string.h>

#include <stdlib.h>
#include <unistd.h>

#ifdef __cplusplus
extern "C" {
#endif



CMPIObjectPath *
makeTimeServiceObjectPath(
		const CMPIBroker *broker,
		const char *ns,
        CMPIStatus *pStatus);


CMPIInstance *
makeTimeServiceInstance(
		const CMPIBroker *broker,
		const char *ns,
        CMPIStatus *pStatus,
        const char **properties);



CMPIObjectPath*
makeRemoteTimeServicePortObjectPath(
	const CMPIBroker *broker,
	const char *ns,
	const char *serverName,
	CMPIStatus *pStatus);


CMPIInstance *
makeRemoteTimeServicePortInstance(
		const CMPIBroker *broker,
		const char *ns,
		const char *serverName,
        CMPIStatus *pStatus,
        const char **properties);



CMPIObjectPath*
makeTimeZoneSettingDataObjectPath(
	const CMPIBroker *broker,
	const char *ns,
	CMPIStatus *pStatus);


CMPIInstance *
makeTimeZoneSettingDataInstance(
		const CMPIBroker *broker,
		const char *ns,
        CMPIStatus *pStatus,
        const char **properties);





int isIPV4Address(const char *arg);

/**
 * Get the timezone, and whether UTC
 * @param: timezone  [out] preallocated string for timezone
 * @param: timezonelen [in] length of timezone - num bytes
 *       allocated
 * @param: utcHwClock [out] int* whether UTC or not
 */
void
cmpiutilGetClockInfo(
		char *timezone,
		int timezoneLen,
		int *utcHwClock);


/**
 * Set the timezone, and whether UTC
 * @param: timezone  [in]  string for new timezone to set
 * @param: utcHwClock [in] int    whether UTC or not
 */
int
cmpiutilSetClockInfo(
		char *timezone,
		int utcHwClock);



#endif // TIME_SERVICE_UTILS_H_GUARD__
