/*******************************************************************************
* Copyright (C) 2005, 2006 Novell, Inc. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
*  - Redistributions of source code must retain the above copyright notice,
*    this list of conditions and the following disclaimer.
*
*  - Redistributions in binary form must reproduce the above copyright notice,
*    this list of conditions and the following disclaimer in the documentation
*    and/or other materials provided with the distribution.
*
*  - Neither the name of Novell, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived from this
*    software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL Novell, Inc. OR THE CONTRIBUTORS
* BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*
* Author: Norm Paxton (npaxton@novell.com)
******************************************************************************/
#ifndef CMPIUTIL_CMPIUTILS_H_GUARD__
#define CMPIUTIL_CMPIUTILS_H_GUARD__

#include <cmpidt.h>
#include <cmpift.h>
#include <cmpimacs.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * Create a new blank instance of a given class with the appropriate property
 * filter set.
 */
CMPIInstance* cmpiutilNewInstance(
		const CMPIBroker *_broker,
		const char *ns,
		const char *className,
		const char** classKeys,
		const char** properties,
		CMPIStatus* pstatus);

/**
 * Create a CMPI Object Path to the computer system
 */
CMPIObjectPath* cmpiutilCreateCSObjectPath(
	const CMPIBroker* _broker,
	const char* ns,
	CMPIStatus* pstatus);

/**
 * Create a CMPI Object path to the Linux OS
 */
CMPIObjectPath* cmpiutilCreateOSObjectPath(
	const CMPIBroker* _broker,
	const char* ns,
	CMPIStatus* pstatus);

/**
 * Create an association cop with provided information
 */
CMPIObjectPath* cmpiutilCreateAssociationPath(
		const CMPIBroker * _broker,
		const char *ns,
		const char *className,
		const char *propName1,
		const char *propName2,
		const CMPIObjectPath *propRef1,
		const CMPIObjectPath *propRef2,
		CMPIStatus* pstatus);
/**
 * Create an association instance with provided information
 */
CMPIInstance* cmpiutilCreateAssociationInst(
		const CMPIBroker * _broker,
		const char *ns,
		const char *className,
		const char **classKeys,
		const char** properties,
		const char *propName1,
		const char *propName2,
		const CMPIObjectPath *propRef1,
		const CMPIObjectPath *propRef2,
		CMPIStatus* pstatus);
/**
 * Is derived class derived from super class?
 */
CMPIBoolean cmpiutilClassIsDerivedFrom(
		const char *derivedClass,
		const char *superClass,
		const CMPIBroker * _broker,
		const char *ns,
		CMPIStatus* pstatus);


/**
 * compare two values - are they the same
 */
CMPIBoolean
cmpiutilAreObjectValuesSame(
		const CMPIData val1,
		const CMPIData val2,
		CMPIStatus *pStatus );


/**
 * compare two object paths - are they the same
 *   compares classname, namespace, numkeys, all key values
 */
CMPIBoolean
cmpiutilAreObjectPathsSame(
		const CMPIObjectPath *cop1,
		const CMPIObjectPath *cop2,
		CMPIStatus *pStatus );
/**
 * Conditionally set the rc on a given status and set/append a message to
 * the existing message in a CMPIStatus
 */
CMPIStatus
cmpiutilSetStatus(
	const CMPIBroker *_broker,
	CMPIStatus* pstatus,
	CMPIrc rc,
	const char* msg,
	const char* fileName,
	int lineno);


/**
 * Given a CMPIObjectPath, create a string-ified version of the
 * object path
 */
/*
CMPIString*
cmpiutilGetStringFromObjectPath(
		CMPIBroker *broker,
		const CMPIObjectPath *cop,
		CMPIStatus *pStatus );
*/
/**
 * A convenience macro for calling cmpiutilSetStatus. This will
 * automatically pass the current file name and line number
 * into the function
 */
#define CMPIUTIL_SETSTATUS(broker, pstatus, rc, msg) cmpiutilSetStatus(broker, pstatus, rc, msg, __FILE__, __LINE__)


#ifdef __cplusplus
}
#endif

#endif
