/*******************************************************************************
* Copyright (C) 2005, 2006 Novell, Inc. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
*  - Redistributions of source code must retain the above copyright notice,
*    this list of conditions and the following disclaimer.
*
*  - Redistributions in binary form must reproduce the above copyright notice,
*    this list of conditions and the following disclaimer in the documentation
*    and/or other materials provided with the distribution.
*
*  - Neither the name of Novell, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived from this
*    software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL Novell, Inc. OR THE CONTRIBUTORS
* BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*
******************************************************************************/


#ifndef CMPIUTIL_FILETOOLS_H_GUARD__
#define CMPIUTIL_FILETOOLS_H_GUARD__

#ifdef __cplusplus
extern "C" {
#endif

struct stat; 

/**
 * Return the name of the directory containing the file (or
 * directory) referenced by path.
 * 
 * @param path The path
 * 
 * @return The directory containing the file.  The caller is
 *         responsible to free the buffer returned.
 */
char* cmpiutil_dirname(const char* path); 

/**
 * Struct containing the six keys of CIM file classes.
 * (CIM_LogicalFile and children)
 */
typedef struct cmpiutilFileKeys_
{
    char * CSCreationClassName; 
    char * CSName; 
    char * CreationClassName; 
    char * FSCreationClassName; 
    char * FSName; 
    char * Name; 
} cmpiutilFileKeys;

/**
 * Free a cmpiutilFileKeys structure and the pointers contained
 * therein.
 * 
 * @param fk pointer to the cmpiutilFileKeys structure to be freed.
 */
void cmpiutilFileKeys_free(cmpiutilFileKeys* fk);

/**
 * Determine the keys for the CIM instance representing a given
 * file.
 * @param path The full path to the file
 * 
 * @return A pointer to an cmpiutilFileKeys structure.  The caller is
 *         responsible to free this with a call to
 *         cmpiutilFileKeys_free().
 */
cmpiutilFileKeys* cmpiutilGetKeysForFile(const char* path); 

/**
 * Determine the keys for the CIM instance representing a given
 * file.  Use this version if you already have a stat for the
 * file and wish to avoid an aditional stat.
 * 
 * @param path The full path to the file
 * @param st A stat structure for the file obtained from stat()
 * 
 * @return A pointer to an cmpiutilFileKeys structure.  The caller is
 *         responsible to free this with a call to
 *         cmpiutilFileKeys_free().
 */
cmpiutilFileKeys* cmpiutilGetKeysForFileStat(const char* path, struct stat* st); 

#ifdef __cplusplus
}
#endif

#endif
