#ifndef CMPIUTIL_LINUXPROCUTILS_H_GUARD__
#define CMPIUTIL_LINUXPROCUTILS_H_GUARD__
#ifdef __cplusplus
extern "C" {
#endif

#include <limits.h>
#include <time.h>
#include <stdint.h>

enum ProcState {
	EPROCSTATE_DoesntExist = -1,		// Process doesn't exist
	EPROCSTATE_Unknown = 0,
	EPROCSTATE_Other = 1,
	EPROCSTATE_Ready = 2,
	EPROCSTATE_Running = 3,
	EPROCSTATE_Blocked = 4,
	EPROCSTATE_SuspendedBlocked = 5,
	EPROCSTATE_SuspendedReady = 6,
	EPROCSTATE_Terminated = 7,
	EPROCSTATE_Stopped = 8,
	EPROCSTATE_Growing = 9
};

typedef struct {
	char execName[PATH_MAX];
	uint64_t kernelModeTime;
	uint32_t niceValue;
	pid_t parentProcessID;
	float percentCPU;
	uint32_t priority;
	uint32_t processGroup;
	uint64_t sessionID;
	time_t startTime;
	enum ProcState state;
	uint32_t ttyNumber;
	uint64_t userModeTime;
	unsigned int virtualMemSize;
	unsigned int residentSetSize;
	unsigned int sharedMemSize;
} process_stats_t;

time_t cmpiutilGetSystemBootTime(void);
enum ProcState cmpiutilGetProcState(pid_t pid);
int cmpiutilValidPidFile(const char* pidFileName, const char* execName);
const char* cmpiutilGetProcExecName(pid_t pid, char* execNameOut,
	size_t execNameOutLen);
int cmpiutilGetAllProcs(pid_t **procsArg, size_t *numProcs,
	const char* regexPattern);
uint64_t cmpiutilGetProcRealUID(pid_t pid);
double cmpiutilGetProcPercentCPU(pid_t pid, int includeDeadChildren);
const char* cmpiutilGetProcCommandLine(pid_t pid, char* cmdLineOut, 
	size_t cmdLineOutLen);
const char* cmpiutilGetProcRootDir(pid_t pid, char* rootDirOut,
	size_t rootDirOutLen);
const char* cmpiutilGetProcCwd(pid_t pid, char* cwdOut, size_t cwdOutLen);
const char* cmpiutilGetProcModulePath(pid_t pid, char* modPathOut,
	size_t modPathOutLen);
pid_t cmpiutilGetProcParentId(pid_t pid);
int cmpiutilGetProcGroup(pid_t pid);
int cmpiutilGetProcTTYNumber(pid_t pid);
int cmpiutilGetProcSessionID(pid_t pid);
int cmpiutilGetProcOwningPGRPOfTTY(pid_t pid);
unsigned long cmpiutilGetProcFlags(pid_t pid);
long cmpiutilGetProcPriority(pid_t pid);
uint64_t cmpiutilGetProcKernelModeTime(pid_t pid);
uint64_t cmpiutilGetUserModeTime(pid_t pid);
long cmpiutilGetProcNiceValue(pid_t pid);
time_t cmpiutilGetProcStartTime(pid_t pid);
unsigned long cmpiutilGetProcVirtualMemSize(pid_t pid);
unsigned long cmpiutilGetProcResidentSetSize(pid_t pid);
unsigned long cmpiutilGetProcSharedMemSize(pid_t pid);
int cmpiutilGetProcStats(pid_t pid, process_stats_t* processStatsOut);

#ifdef __cplusplus
}
#endif

#endif	/* CMPIUTIL_LINUXPROCUTILS_H_GUARD__ */
