/*******************************************************************************
* Copyright (C) 2005, 2006 Novell, Inc. All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
*  - Redistributions of source code must retain the above copyright notice,
*    this list of conditions and the following disclaimer.
*
*  - Redistributions in binary form must reproduce the above copyright notice,
*    this list of conditions and the following disclaimer in the documentation
*    and/or other materials provided with the distribution.
*
*  - Neither the name of Novell, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived from this
*    software without specific prior written permission.
*
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
* AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
* ARE DISCLAIMED. IN NO EVENT SHALL Novell, Inc. OR THE CONTRIBUTORS
* BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
* SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
* INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
* CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
* ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
* POSSIBILITY OF SUCH DAMAGE.
*
* Author: Norm Paxton (npaxton@novell.com)
******************************************************************************/
#ifndef NTP_SERVER_UTILS_H_GUARD__
#define NTP_SERVER_UTILS_H_GUARD__


#define NTP_SERVER_NAME_LEN 256

typedef struct
{
	char serverName[NTP_SERVER_NAME_LEN];
	int prefer;
	int key;
	int ntpVersion;
	int minPoll;
	int maxPoll;
} NTPServer;


/*
  Determine if the local computer supports NTPServer
*/
int
serverSupportsNTP();


/*
  get an array of NTPServers with [pCount] elements
  Caller is responsible to free the pointer returned
*/
NTPServer *
getNTPServers(
		int *pCount);


/*
  get the NTPServer that corresponds with [serverName]
  Caller is responsible to free the pointer returned
*/
NTPServer *
getNTPServer(
		const char *serverName);


/*
  delete the NTPServer that corresponds with [serverName]
*/
int
deleteNTPServer(
		const char *serverName);


/*
  modify the settings of NTPServer that corresponds with [oldServerName]
*/
int
setNTPServer(
		const char *oldServerName,
		NTPServer *server);


/*
  c version of assignment operator
*/
void
copyNTPServer(
		const NTPServer *in,
		NTPServer *out);


/*
  c version of copy constructor
  Caller is responsible to free the pointer returned
*/
NTPServer *
createAndCopyNTPServer(
		const NTPServer *in);


#endif // NTP_SERVER_UTILS_H_GUARD__

